branch: externals/posframe
commit 3583a21a880aae019d9422ece0cb80398a7d4ccb
Author: Štěpán Němec <[email protected]>
Commit: Štěpán Němec <[email protected]>
More documentation language improvements
---
posframe.el | 26 +++++++++++++-------------
1 file changed, 13 insertions(+), 13 deletions(-)
diff --git a/posframe.el b/posframe.el
index e2b7aa0..49082f6 100644
--- a/posframe.el
+++ b/posframe.el
@@ -28,15 +28,15 @@
;;; Commentary:
;; * Posframe README :README:
-;; ** What is posframe
-;; Posframe can pop a posframe at point, this *posframe* is a
-;; child-frame with its root window's buffer.
+;; ** What is posframe?
+;; Posframe can pop up a frame at point, this *posframe* is a
+;; child-frame connected to its root window's buffer.
;; The main advantages are:
;; 1. It is fast enough for daily usage :-)
-;; 2. It works well with CJK language.
+;; 2. It works well with CJK languages.
-;; NOTE: For MacOS users, posframe need Emacs (version >= 26.0.91)
+;; NOTE: For MacOS users, posframe needs Emacs version >= 26.0.91
;; [[./snapshots/posframe-1.png]]
@@ -101,11 +101,11 @@
;; M-x posframe-delete-all
;; #+END_EXAMPLE
-;; Note: this command will delete all posframe buffers,
-;; suggest not run this command if you are sharing a buffer
+;; Note: this command will delete all posframe buffers.
+;; You probably shouldn't use it if you are sharing a buffer
;; between posframe and other packages.
-;; *** Customizing pointer control
+;; *** Customizing mouse pointer control
;; By default, posframe moves the pointer to point (0,0) in
;; the frame, as a way to address an issue with mouse focus.
@@ -114,10 +114,10 @@
;; (setq posframe-mouse-banish nil)
;; #+END_EXAMPLE
;; *** Set fallback argument of posframe-show
;; user can set fallback values of posframe-show's arguments with the
;; help of `posframe-arghandler'. the below example set fallback
;; border-width to 10 and fallback background color to green.
;; #+BEGIN_EXAMPLE
@@ -149,8 +149,8 @@
(defcustom posframe-arghandler #'posframe-arghandler-default
"A function used to handle posframe-show's argument.
-User can use this feature to set the default value of
-posframe-show's argument."
+Users can use this feature to set the default value of
+posframe-show's arguments."
:group 'posframe
:type 'function)
@@ -114,10 +114,10 @@
;; (setq posframe-mouse-banish nil)
;; #+END_EXAMPLE
-;; *** Set fallback argument of posframe-show
+;; *** Set fallback arguments of posframe-show
-;; user can set fallback values of posframe-show's arguments with the
-;; help of `posframe-arghandler'. the below example set fallback
+;; Users can set fallback values of posframe-show's arguments with the
+;; help of `posframe-arghandler'. The example below sets fallback
;; border-width to 10 and fallback background color to green.
;; #+BEGIN_EXAMPLE